@@ -66,9 +66,6 @@ class Volume(object):
     def __str__(self):
         return str(self.__unicode__())
 
-    def __cmp__(self, other):
-        return cmp(self.lastmountpoint, other.lastmountpoint)
-
     # noinspection PyProtectedMember
     def _debug(self, val):
         if self.disk:
@@ -360,6 +357,8 @@ class Volume(object):
         # noinspection PyBroadException
         try:
             cmd = ["cryptsetup", "luksOpen", self.loopback, self.luks_path]
+            if not self.disk.read_write:
+                cmd.insert(1, '-r')
             util.check_call_(cmd, self)
         except Exception:
             self.luks_path = None
